@@ -32,6 +32,7 @@ module Snap.Http.Server.Config
   , getSSLBind
   , getSSLCert
   , getSSLKey
+  , getSSLChainCert
   , getSSLPort
   , getVerbose
   , getStartupHook
@@ -50,6 +51,7 @@ module Snap.Http.Server.Config
   , setSSLBind
   , setSSLCert
   , setSSLKey
+  , setSSLChainCert
   , setSSLPort
   , setVerbose
   , setStartupHook
